#!/bin/sh -e

case "$1" in
#at4x0a)
#	PLATFORM="at4x0a"
#	CROSS_BUILD="i686-pc-linux-gnu"
#	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
#	CROSS_OPT="-O2"
#	CROSS_CPU="arm926ej-s"
#	;;
#""|s3c24xx)
#	PLATFORM="s3c24xx"
#	CROSS_BUILD="i686-linux"
#	CROSS_TARGET="arm-linux"
#	CROSS_OPT="-O2"
#	CROSS_CPU="arm920"
#	;;
#omap2)
#	PLATFORM="omap2"
#	CROSS_BUILD="i686-pc-linux-gnu"
#	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
#	CROSS_OPT="-O2"
#	CROSS_CPU="arm1136jf-s"
#	;;
bcm4760)
        PLATFORM="bcm4760"
        CROSS_BUILD="i686-pc-linux-gnu"
        CROSS_TARGET="arm-none-linux-gnueabi"
        CROSS_OPT="-O2"
        CROSS_CPU="arm1136jf-s"
        ;;
s3c64xx)
	PLATFORM="s3c64xx"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-none-linux-gnueabi"
  CROSS_OPT="-O2 -mcpu=arm1176jzf-s -mfpu=vfp -mfp=vfp -march=armv6k -mtune=arm1176jzf-s -mfloat-abi=softfp"
	CROSS_CPU="arm1176jzf-s"
	;;
titan2)
	PLATFORM="titan2"
	CROSS_BUILD="i686-pc-linux-gnu"
	#CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	# Using temp CodeSourcery toolchain
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
*)
	echo "$0: ERROR: Unknown platform \"$1\"."
	echo "only titan2 and s3c64xx is supported."
        exit 1
	;;
esac

PROGNAME="plugz-lib"
SRCDIR="${PWD}"

OBJDIR="${PWD}/obj-${PLATFORM}"
INSDIR="${PWD}/ins-${PLATFORM}"

export BUILD_CC="gcc"
export CC="${CROSS_TARGET}-gcc"
export CFLAGS="${CROSS_OPT} -mcpu=${CROSS_CPU} -ffunction-sections -fdata-sections"
export CXX="${CROSS_TARGET}-g++"
export CXXFLAGS="${CFLAGS}"
export F77="${CROSS_TARGET}-g77"
export AS="${CROSS_TARGET}-as"
export LD="${CROSS_TARGET}-ld"
#DO NOT use the --gc-sections flag to the linker, it will strip the versioning information
# that alsa needs when built as shared library!!!!!!
#export LDFLAGS="-Wl,--gc-sections"
export AR="${CROSS_TARGET}-ar"
export NM="${CROSS_TARGET}-nm"
export RANLIB="${CROSS_TARGET}-ranlib"
export STRIP="${CROSS_TARGET}-strip"

# vars to get configure to locate bluez
export THIRDPARTY_BASE_DIR="`pwd`/../../.."

# Let the following depend on the platform
case "${PLATFORM}" in
s3c64xx|bcm4760)
  export DBUS_LIBS="-L${THIRDPARTY_BASE_DIR}/dbus/dist/1.2.4/Linux/${PLATFORM} -ldbus-1"
  export DBUS_CFLAGS="-I${THIRDPARTY_BASE_DIR}/dbus/dist/1.2.4/Include/dbus-1.0"    
  export BLUEZ_CFLAGS="-I${THIRDPARTY_BASE_DIR}/bluez/dist/3.24/Include"
  export BLUEZ_LIBS="-L${THIRDPARTY_BASE_DIR}/bluez/dist/3.24/Linux/lib-${PLATFORM} -lbluetooth"
  ;;
titan2)
  export BLUEZ_CFLAGS="-I${THIRDPARTY_BASE_DIR}/bluez/dist/3.24/Include"
  export BLUEZ_LIBS="-L${THIRDPARTY_BASE_DIR}/bluez/dist/3.24/Linux/lib-${PLATFORM} -lbluetooth"
  export DBUS_LIBS="-L${THIRDPARTY_BASE_DIR}/dbus/dist/1.0.2/Linux/${PLATFORM} -ldbus-1"
  export DBUS_CFLAGS="-I${THIRDPARTY_BASE_DIR}/dbus/dist/1.0.2/Include/dbus-1.0"
	;;
*)
  export BLUEZ_CFLAGS="-I${THIRDPARTY_BASE_DIR}/bluez/dist/libs-2.15/Include"
  export BLUEZ_LIBS="-L${THIRDPARTY_BASE_DIR}/bluez/dist/libs-2.15/Linux/lib-${PLATFORM} -lbluetooth"
  export DBUS_LIBS="-L${THIRDPARTY_BASE_DIR}/dbus/dist/1.0.2/Linux/${PLATFORM} -ldbus-1"
  export DBUS_CFLAGS="-I${THIRDPARTY_BASE_DIR}/dbus/dist/1.0.2/Include/dbus-1.0"
	;;   
esac

export ALSA_CFLAGS="-I${THIRDPARTY_BASE_DIR}/alsa-lib/dist/1.0.16/Include"
export ALSA_LIBS="-L${THIRDPARTY_BASE_DIR}/alsa-lib/dist/1.0.16/Linux/lib-${PLATFORM} -lasound"

export GLIB_LIBS="-L${THIRDPARTY_BASE_DIR}/glib/dist/2.10.3/Linux/${PLATFORM} -lglib-2.0"
export GLIB_CFLAGS="-I${THIRDPARTY_BASE_DIR}/glib/dist/2.10.3/Include \
                    -I${THIRDPARTY_BASE_DIR}/glib/dist/2.10.3/Include/glib-2.0 \
                    -I${THIRDPARTY_BASE_DIR}/glib/dist/2.10.3/Linux/${PLATFORM}/glib-2.0/include"


export LIBGTHREAD="-L${THIRDPARTY_BASE_DIR}/glib/dist/2.10.3/Linux/${PLATFORM} -lgthread-2.0"
		    
export CFLAGS="${CFLAGS} ${BLUEZ_CFLAGS} ${ALSA_CFLAGS} ${GLIB_CFLAGS} ${DBUS_CFLAGS}"

export LDFLAGS="${LDFLAGS} -ldl ${GLIB_LIBS} ${DBUS_LIBS} ${LIBGTHREAD} ${BLUEZ_LIBS} ${ALSA_LIBS}"


if test -e "configure"; then
  rm -f configure
fi
autoconf

mkdir -p "${OBJDIR}"
cd "${OBJDIR}"

echo "**** Configuring ${PROGNAME} for ${PLATFORM}..."
"${SRCDIR}/configure"		\
  --build="${CROSS_BUILD}"	\
  --host="${CROSS_TARGET}"	\
  --target="${CROSS_TARGET}"	\
  --prefix="/"                  

 echo "**** Building ${PROGNAME} for ${PLATFORM}..."
make

echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make DESTDIR="${INSDIR}" install

echo "**** Successfully built & installed ${PROGNAME} for ${PLATFORM}:"
ls -l "${INSDIR}/lib"

# EOF
